<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Wp_Dxp
 * @subpackage Wp_Dxp/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Wp_Dxp
 * @subpackage Wp_Dxp/admin
 * @author     Your Name <email@example.com>
 */
class Wp_Dxp_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $wp_dxp    The ID of this plugin.
	 */
	private $wp_dxp;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $wp_dxp       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $wp_dxp, $version ) {

		$this->wp_dxp = $wp_dxp;
		$this->version = $version;
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wp_Dxp_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wp_Dxp_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		if ($this->isWpDxpPage()) {
			wp_enqueue_style( $this->wp_dxp . '_bootstrap', plugin_dir_url( __FILE__ ) . 'css/wp-dxp-bootstrap.min.css', array(), $this->version, 'all' );
			wp_enqueue_style( $this->wp_dxp . '_chosen', plugin_dir_url( __FILE__ ) . 'css/wp-dxp-chosen.css', array(), $this->version, 'all' );
			wp_enqueue_style( $this->wp_dxp . '_datatables', plugin_dir_url( __FILE__ ) . 'css/wp-dxp-dataTables.bootstrap4.min.css', array($this->wp_dxp . '_bootstrap'), $this->version, 'all' );

			wp_enqueue_style( $this->wp_dxp, plugin_dir_url( __FILE__ ) . 'css/wp-dxp-admin.css', array(), $this->version, 'all' );
		}

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wp_Dxp_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wp_Dxp_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		if ($this->isWpDxpPage()) {
			wp_enqueue_script( $this->wp_dxp . '_bootstrap', plugin_dir_url( __FILE__ ) . 'js/wp-dxp-bootstrap.min.js', array('jquery'), $this->version, false );
			wp_enqueue_script( $this->wp_dxp . '_chosen', plugin_dir_url( __FILE__ ) . 'js/wp-dxp-admin.chosen.jquery.js', array('jquery'), $this->version, false );
			wp_enqueue_script( $this->wp_dxp . '_datatables', plugin_dir_url( __FILE__ ) . 'js/wp-dxp-jquery.dataTables.min.js', array('jquery'), $this->version, false );
			wp_enqueue_script( $this->wp_dxp . '_bootstrap_datatables', plugin_dir_url( __FILE__ ) . 'js/wp-dxp-dataTables.bootstrap4.min.js', array($this->wp_dxp . '_bootstrap', $this->wp_dxp . '_datatables'), $this->version, false );

			wp_enqueue_script( $this->wp_dxp, plugin_dir_url( __FILE__ ) . 'js/wp-dxp-admin.js', array( 'jquery' ), $this->version, false );
		}
	}

	public function enqueue_block_editor_scripts()
	{
		$properties = require(plugin_dir_path( dirname( __FILE__ ) ). 'build/index.asset.php');

		wp_enqueue_script( $this->wp_dxp.'-blocks', plugin_dir_url( __FILE__ ) . '../build/index.js', array('wp-blocks', 'wp-editor') + $properties['dependencies'], $properties['version'], false );
	}

	/**
	 * Dashboard page
	 * @return null
	 */
	public function dashboardMenu() {
		Wp_Dxp_Admin_Dashboard_Page::getInstance()
			->route();
	}

	/**
	 * Rules page
	 * @return null
	 */
	public function rulesMenu() {
		Wp_Dxp_Admin_Rules_Page::getInstance()
			->route();
	}

	/**
	 * Categories page
	 * @return null
	 */
	public function categoriesMenu() {
		Wp_Dxp_Admin_Categories_Page::getInstance()
			->route();
	}

	/**
	 * Personalisation page
	 * @return null
	 */
	public function personalisationMenu() {
		Wp_Dxp_Admin_Personalisation_Page::getInstance()
			->route();
	}

	/**
	 * Help page
	 * @return null
	 */
	public function helpMenu() {
		Wp_Dxp_Admin_Help_Page::getInstance()
			->route();
	}

	/**
	 * Create menu items for WP-DXP
	 * @return null
	 */
	public function createAdminMenu() {
		add_menu_page(
			__( 'WP-DXP', 'wp-dxp' ),
			__( 'WP-DXP', 'wp-dxp' ),
			'manage_options',
			WP_DXP_ADMIN_SLUG,
			[$this, 'dashboardMenu'],
			'dashicons-layout',
			21
		);

		add_submenu_page(
			WP_DXP_ADMIN_SLUG,
			__( 'Dashboard', 'wp-dxp' ),
			__( 'Dashboard', 'wp-dxp' ),
			'manage_options',
			WP_DXP_ADMIN_SLUG,
			[$this, 'dashboardMenu']
		);

		$request = Wp_Dxp_Request::getInstance();
		$page = $request->get('page');
		$action = $request->get('wp_dxp_action');

		$ruleItemTitle = !empty($page) && $page == WP_DXP_ADMIN_RULES_SLUG && !empty($action) && $action == 'edit' ? 'Edit Rule' : 'Add Rule';
		add_submenu_page(
			WP_DXP_ADMIN_SLUG,
			__( $ruleItemTitle, 'wp-dxp' ),
			__( $ruleItemTitle, 'wp-dxp' ),
			'manage_options',
			WP_DXP_ADMIN_RULES_SLUG,
			[$this, 'rulesMenu']
		);

		add_submenu_page(
			WP_DXP_ADMIN_SLUG,
			__( 'Categories', 'wp-dxp' ),
			__( 'Categories', 'wp-dxp' ),
			'manage_options',
			WP_DXP_ADMIN_CATEGORIES_SLUG,
			[$this, 'categoriesMenu']
		);

		/*add_submenu_page(
			WP_DXP_ADMIN_SLUG,
			__( 'Personalisation', 'wp-dxp' ),
			__( 'Personalisation', 'wp-dxp' ),
			'manage_options',
			WP_DXP_ADMIN_PERSONALISATION_SLUG,
			[$this, 'personalisationMenu']
		);*/

		add_submenu_page(
			WP_DXP_ADMIN_SLUG,
			__( 'Help', 'wp-dxp' ),
			__( 'Help', 'wp-dxp' ),
			'manage_options',
			WP_DXP_ADMIN_HELP_SLUG,
			[$this, 'helpMenu']
		);
	}

	/**
	 * Call process function on page class (usually to process POST data)
	 */
	public function process()
	{
		$request = Wp_Dxp_Request::getInstance();
		$page = $request->get('page', false);

		switch ($page) {
			case WP_DXP_ADMIN_SLUG:
				Wp_Dxp_Admin_Dashboard_Page::getInstance()
					->process();
				break;
			case WP_DXP_ADMIN_CATEGORIES_SLUG:
				Wp_Dxp_Admin_Categories_Page::getInstance()
					->process();
				break;
			case WP_DXP_ADMIN_RULES_SLUG:
				Wp_Dxp_Admin_Rules_Page::getInstance()
					->process();
				break;
		}
	}

	/**
	 * Register API routes for the plugin
	 */
	public function registerApiRoutes()
	{
		register_rest_route( 'wp-dxp/v1', '/rules', [
		    'methods' => 'GET',
		    'callback' => [$this, 'getRulesApi'],
		]);
	}

	/**
	 * Return all rules to be used in gutenberg block setting
	 * @return object|array
	 */
	public function getRulesApi()
	{
		$rules = Wp_Dxp_Rule::all();

		$data = [];
		foreach ($rules as $rule) {
			$data[] = [
				'id' => $rule->id,
				'name' => $rule->name,
				'is_usable' => $rule->is_usable,
			];
		}
		return [
			'data' => $data
		];
	}

	/**
	 * Function executed when the 'admin_notices' action is called, here we check if there are notices on
	 * our database and display them, after that, we remove the option to prevent notices being displayed forever.
	 * @return void
	 */
	public function displayAdminNotices() {
	    $notices = get_option(WP_DXP_ADMIN_NOTICES_OPTION_KEY, []);

	    // Iterate through our notices to be displayed and print them.
	    foreach ( $notices as $notice ) {
	        printf('<div class="notice notice-%1$s %2$s"><p>%3$s</p></div>',
	            $notice['type'],
	            $notice['dismissible'],
	            $notice['notice']
	        );
	    }

	    // Now we reset our options to prevent notices being displayed forever.
	    if(!empty($notices)) {
	        delete_option(WP_DXP_ADMIN_NOTICES_OPTION_KEY, []);
	    }
	}

	/**
	 * Run DB migrations
	 */
	public function migrateDb()
	{
		Wp_Dxp_DB_Manager::getInstance()
			->migrate();
	}

	/**
	 * Is the current page an admin page?
	 * @return boolean
	 */
	protected function isWpDxpPage()
	{
		$request = Wp_Dxp_Request::getInstance();
		$page = $request->get('page');

		$pages = [
			WP_DXP_ADMIN_SLUG,
			WP_DXP_ADMIN_CATEGORIES_SLUG,
			WP_DXP_ADMIN_RULES_SLUG,
			WP_DXP_ADMIN_PERSONALISATION_SLUG,
			WP_DXP_ADMIN_HELP_SLUG,
		];

		return is_admin() && !empty($page) && in_array($page, $pages);
	}

}
