<?php

/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Wp_Dxp
 * @subpackage Wp_Dxp/admin/partials
 */
?>

<!-- This file should primarily consist of HTML with a little bit of PHP. -->

<div class="container-fluid pl-0 pr-0 wp-dxp-header-nav">

    <?php
    require_once plugin_dir_path( dirname( __FILE__ ) ) . '_other/wp-dxp-header-nav.php'; ?>

</div>

<section class="section wp-dxp-body-content">
    <div class="container-fluid">
        <div class="row mb-lg-2">
            <div class="col-12 d-inline-flex align-items-center justify-content-between">
                <h2 class="h4 section-title mb-2"><?php _e('Active Rules', 'wp-dxp'); ?></h2>
            </div>
        </div>
        <div class="row mb-3">
            <div class="col-12">
                <p class="section-description"><?php _e('Rules that are active will be displayed to a user and are available to use. Click on View/Edit to find out more information about the rule.', 'wp-dxp'); ?></p>
            </div>
        </div>
        <div class="row">
            <div class="col-12">
                <div class="table-responsive-lg">
                    <table class="datatable_dashboard table table-striped table-bordered">
                        <thead>
                            <tr>
                                <th><?php _e('Rule Name', 'wp-dxp'); ?></th>
                                <th><?php _e('Category', 'wp-dxp'); ?></th>
                                <th><?php _e('Type', 'wp-dxp'); ?></th>
                                <th><?php _e('Created By', 'wp-dxp'); ?></th>
                                <th><?php _e('Used By', 'wp-dxp'); ?></th>
                                <th>&nbsp;</th>
                            </tr>
                        </thead>

                        <tbody>
                            <?php
                            foreach ($rules as $i => $rule) :
                                if ($rule->is_usable) : ?>
                            <tr class="<?php echo $i % 2 ? 'alternate' : ''; ?>">
                                <td><?php echo esc_attr($rule->name); ?></td>
                                <td><?php echo esc_attr($rule->category_name); ?></td>
                                <td><?php echo esc_attr($rule->type_friendly); ?></td>
                                <td>
                                    <?php
                                    if ($rule->created_by) : ?>
                                    <a href="/wp-admin/user-edit.php?user_id=<?php echo $rule->created_by; ?>" class="table-link"><?php echo esc_attr($rule->created_by_friendly); ?></a>
                                    <?php
                                    else : ?>
                                    <?php echo esc_attr($rule->created_by_friendly); ?>
                                    <?php
                                    endif; ?>
                                </td>
                                <td><?php echo esc_attr($rule->usage_blocks_count); ?> <?php echo $rule->usage_blocks_count == 1 ? 'block' : 'blocks'; ?></td>
                                <td>
                                    <div class="d-flex justify-content-center">
                                        <a class="table-link mx-1" href="<?php echo $rule->edit_url; ?>"><?php echo $rule->can_edit ? 'Edit' : 'View'; ?></a>
                                        <?php
                                        if ($rule->can_duplicate) : ?> |
                                        <a class="table-link mx-1" href="<?php echo $rule->duplicate_url; ?>">Duplicate</a>
                                        <?php
                                        endif; ?>
                                        <?php
                                        if ($rule->can_delete) : ?>
                                            | <a class="table-link mx-1 wp-dxp-delete-rule" href="<?php echo $rule->delete_url; ?>">Delete</a>
                                        <?php
                                        endif; ?>
                                    </div>
                                </td>
                            </tr>
                            <?php
                                endif;
                            endforeach; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
</section>

<section class="section">
    <div class="container-fluid">
        <div class="row mb-lg-2">
            <div class="col-12 d-inline-flex align-items-center justify-content-between">
                <h2 class="h4 section-title mb-2"><?php _e('Inactive Rules', 'wp-dxp'); ?></h2>
            </div>
        </div>
        <div class="row mb-3">
            <div class="col-12">
                <p class="section-description"><?php _e('Rules that are inactive will mean that content related to them will not currently be displayed to a user. Reasons these rules are "inactive" include dependence upon a third party plugin to function (for example WooCommerce). Click on View/Edit to determine why a rule is not currently usable.', 'wp-dxp'); ?></p>
            </div>
        </div>
        <div class="row">
            <div class="col-12">
                <div class="table-responsive-lg">
                    <table class="datatable_dashboard table table-striped table-bordered">
                        <thead>
                            <tr>
                                <th><?php _e('Rule Name', 'wp-dxp'); ?></th>
                                <th><?php _e('Category', 'wp-dxp'); ?></th>
                                <th><?php _e('Type', 'wp-dxp'); ?></th>
                                <th><?php _e('Created By', 'wp-dxp'); ?></th>
                                <th><?php _e('Used By', 'wp-dxp'); ?></th>
                                <th>&nbsp;</th>
                            </tr>
                        </thead>

                        <tbody>
                            <?php
                            foreach ($rules as $i => $rule) :
                                if (!$rule->is_usable) : ?>
                            <tr class="<?php echo $i % 2 ? 'alternate' : ''; ?>">
                                <td><?php echo esc_attr($rule->name); ?></td>
                                <td><?php echo esc_attr($rule->category_name); ?></td>
                                <td><?php echo esc_attr($rule->type_friendly); ?></td>
                                <td>
                                    <?php
                                    if ($rule->created_by) : ?>
                                    <a href="/wp-admin/user-edit.php?user_id=<?php echo $rule->created_by; ?>" class="table-link"><?php echo esc_attr($rule->created_by_friendly); ?></a>
                                    <?php
                                    else : ?>
                                    <?php echo esc_attr($rule->created_by_friendly); ?>
                                    <?php
                                    endif; ?>
                                </td>
                                <td><?php echo esc_attr($rule->usage_blocks_count); ?> <?php echo $rule->usage_blocks_count == 1 ? 'block' : 'blocks'; ?></td>
                                <td>
                                    <div class="d-flex justify-content-center">
                                        <a class="table-link mx-1" href="<?php echo $rule->edit_url; ?>"><?php echo $rule->can_edit ? __('Edit', 'wp-dxp') : __('View', 'wp-dxp'); ?></a>
                                        <?php
                                        if ($rule->can_duplicate) : ?> |
                                        <a class="table-link mx-1" href="<?php echo $rule->duplicate_url; ?>"><?php _e('Duplicate', 'wp-dxp'); ?></a>
                                        <?php
                                        endif; ?>
                                        <?php
                                        if ($rule->can_delete) : ?>
                                            | <a class="table-link mx-1 wp-dxp-delete-rule" href="<?php echo $rule->delete_url; ?>"><?php _e('Delete', 'wp-dxp'); ?></a>
                                        <?php
                                        endif; ?>
                                    </div>
                                </td>
                            </tr>
                            <?php
                                endif;
                            endforeach; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
</section>

<?php
require_once plugin_dir_path( dirname( __FILE__ ) ) . '_other/wp-dxp-footer.php'; ?>