<?php
if ($this->getError('form')) : ?>
<div class="alert alert-danger" role="alert">
    <?php
    echo implode($this->getError('form'), '<br />'); ?>
</div>
<?php
endif; ?>

<?php echo Wp_Dxp_Form::wpNonceField(WP_DXP_FORM_NONCE_FIELD_ACTION); ?>

<?php echo Wp_Dxp_Form::hidden('id', $rule->id); ?>

<div class="row mb-4">
    <div class="col-12 col-lg-6">
        <div class="form-group mb-2">
            <label for="wp_dxp_form[name]"><?php _e('Rule Name', 'wp-dxp'); ?></label>
            <?php echo Wp_Dxp_Form::text('name', esc_attr($rule->name), 'class="form-control ' . ($this->getError('name') ? 'is-invalid' : '') . '"'); ?>
            <?php
            if ($this->getError('name')) : ?>
            <div class="invalid-feedback"><?php echo implode(', ', $this->getError('name')); ?></div>
            <?php
            endif; ?>
        </div>
    </div>
</div>


<div class="row mb-4">
    <div class="col-12 col-lg-6">
        <div class="form-group mb-2 category-dropdown">
            <label for="wp_dxp_form[category_id]"><?php _e('Category', 'wp-dxp'); ?></label>
            <?php echo Wp_Dxp_Form::select('category_id', [null => '-- Select a category --'] + Wp_Dxp_Category::list(), $rule->category_id, 'class="chosen-select form-control ' . ($this->getError('category_id') ? 'is-invalid' : '') . '"'); ?>
            <?php
            if ($this->getError('category_id')) : ?>
            <div class="invalid-feedback"><?php echo implode(', ', $this->getError('category_id')); ?></div>
            <?php
            endif; ?>
        </div>
    </div>
</div>

<div class="row">
    <div class="col-12 col-lg-10">
        <div class="form-group mb-2">
            <label><?php _e('Conditions', 'wp-dxp'); ?></label>
            <div class="conditions">
                <?php
                if ($rule->conditions) :
                    foreach ($rule->conditions as $i => $condition) : ?>

                        <div class="condition mb-2">

                            <?php echo Wp_Dxp_Form::select('[conditions][measure][]', [null => '-- Select a measure --'] + Wp_Dxp_Conditions::groupedList(), $condition->measure, 'class="conditions-measure chosen-select"'); ?>

                            <?php echo Wp_Dxp_Form::select('[conditions][comparator][]', [null => '-- Select a comparator --'] + Wp_Dxp_Conditions::getComparatorList($condition->measure), $condition->comparator, 'class="conditions-comparator chosen-select"'); ?>

                            <?php echo Wp_Dxp_Form::select('[conditions][value][]', [null => '-- Select a value --'] + Wp_Dxp_Conditions::getComparisonValues($condition->measure), $condition->value, 'class="conditions-value chosen-select"' . ($condition->comparator == 'any' ? ' multiple' : '')); ?>

                            <?php echo Wp_Dxp_Form::hidden('[conditions][raw_value][]', $condition->raw_value, 'class="conditions-raw-value"'); ?>

                            <button class="add-condition">&plus;</button>
                            <?php
                            if ($i > 0) : ?>
                            <button class="remove-condition">&minus;</button>
                            <?php
                            endif; ?>

                        </div>
                        <?php
                        if ($this->getError("conditions[{$i}]")) : ?>
                        <div class="form-control is-invalid" style="display: none;"></div>
                        <div class="invalid-feedback"><?php echo implode(', ', $this->getError("conditions[{$i}]")); ?></div>
                        <?php
                        endif; ?>

                    <?php
                    endforeach;
                else: ?>
                    <div class="condition mb-2">
                        <?php echo Wp_Dxp_Form::select('[conditions][measure][]', [null => '-- Select a measure --'] + Wp_Dxp_Conditions::groupedList(), null, 'class="conditions-measure chosen-select"'); ?>

                        <?php echo Wp_Dxp_Form::select('[conditions][comparator][]', [null => '-- Select a comparator --'], null, 'class="conditions-comparator chosen-select"'); ?>

                        <?php echo Wp_Dxp_Form::select('[conditions][value][]', [null => '-- Select a value --'], null, 'class="conditions-value chosen-select"'); ?>

                        <?php echo Wp_Dxp_Form::hidden('[conditions][raw_value][]', '', 'class="conditions-raw-value"'); ?>

                        <button class="add-condition">&plus;</button>
                        <button class="remove-condition invisible">&minus;</button>

                    </div>
                    <?php
                    if ($this->getError('conditions[0]')) : ?>
                    <div class="form-control is-invalid" style="display: none;"></div>
                    <div class="invalid-feedback"><?php echo implode(', ', $this->getError('conditions[0]')); ?></div>
                    <?php
                    endif; ?>

                <?php
                endif; ?>

                <div id="condition-template" style="display:none;">
                    <div class="condition mb-2">

                        <?php echo Wp_Dxp_Form::select('[conditions][measure][]', [null => '-- Select a measure --'] + Wp_Dxp_Conditions::groupedList(), null, 'class="conditions-measure" disabled="disabled"'); ?>

                        <?php echo Wp_Dxp_Form::select('[conditions][comparator][]', [null => '-- Select a comparator --'], null, 'class="conditions-comparator" disabled="disabled"'); ?>

                        <?php echo Wp_Dxp_Form::select('[conditions][value][]', [null => '-- Select a value --'], null, 'class="conditions-value" disabled="disabled"'); ?>

                        <?php echo Wp_Dxp_Form::hidden('[conditions][raw_value][]', '', 'class="conditions-raw-value" disabled="disabled"'); ?>

                        <button class="add-condition">&plus;</button>
                        <button class="remove-condition">&minus;</button>
                    </div>
                </div>

                <script type="text/javascript">
                    var wpDxpConditions = <?php echo Wp_Dxp_Conditions::toJson(); ?>;
                </script>
            </div>
        </div>
    </div>
</div>





<div class="mt-4">

    <?php
    if ($rule->can_edit) : ?>
        <button class="btn"><?php _e('Save Rule', 'wp-dxp'); ?></button>
    <?php
    else : ?>
        <p class="rule-message"><?php _e('NOTE: Standard rules cannot be edited, however you can duplicate this rule and make your own changes.', 'wp-dxp'); ?></p>
    <?php
    endif; ?>

</div>


<script type="text/javascript">
(function( $ ) {
    'use strict';

    $(".chosen-select").chosen();

    if (typeof wpDxpConditions !== 'undefined') {
        var $conditionTemplate = $('#condition-template .condition');
        var $comparatorEl;
        var $valueEl;

        $(document).on('change', '.conditions-measure', function() {
            wp_dxp_measure_set_related_fields(this);
        });

        $(document).on('change', '.conditions-comparator', function() {
            wp_dxp_set_value_field_type(this);
        });

        $(document).on('change', '.conditions-value', function() {
            wp_dxp_set_raw_value_field_value(this);
        });

        $(document).on('click', '.remove-condition', function(e) {
            $(this).parent().remove();
            e.preventDefault();
        });

        $(document).on('click', '.add-condition', function(e) {
            var $template = $conditionTemplate.clone();

            $template.children('select, input').prop("disabled", false);

            var value = $template.children('.conditions-value').first().val();
            $template.children('.conditions-raw-value').val(value);

            $(this).parent().parent().append($template);

            $template.children('select').chosen();
            e.preventDefault();
        });
    }

    function wp_dxp_set_value_field_type(el) {
        var $parent = $(el).parent();
        var comparator = $(el).val();

        var $valueEl = $parent.children('.conditions-value');
        $valueEl.prop("multiple", (comparator == 'any') ? "multiple" : "");
        $valueEl.chosen('destroy');
        $valueEl.chosen();
    }

    function wp_dxp_measure_set_related_fields(el) {
        var $parent = $(el).parent();
        var measure = $(el).val();

        var $comparatorEl = $parent.children('.conditions-comparator');
        var $valueEl = $parent.children('.conditions-value');

        $comparatorEl.find('option').not(':first').remove();
        $valueEl.find('option').not(':first').remove();
        if (typeof wpDxpConditions[measure] !== 'undefined') {
            $.each(wpDxpConditions[measure].comparators, function(key,value) {
                $comparatorEl.append($("<option></option>")
                    .attr("value", key).text(value));
            });

            $.each(wpDxpConditions[measure].comparisonValues, function(key,value) {
                $valueEl.append($("<option></option>")
                    .attr("value", key).text(value));
            });
        }

        $comparatorEl.chosen('destroy');
        $comparatorEl.chosen();
        wp_dxp_set_value_field_type(el);
        wp_dxp_set_raw_value_field_value(el);
    }

    function wp_dxp_set_raw_value_field_value(el) {
        var $parent = $(el).parent();

        var $valueEl = $parent.children('.conditions-value');
        var $rawValuesEl = $parent.children('.conditions-raw-value').first();
        var value = $valueEl.val();

        if (Array.isArray(value)) {
            $rawValuesEl.val(JSON.stringify(value));
        } else {
            $rawValuesEl.val(value);
        }
    }

})( jQuery );

</script>