<?php

/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Wp_Dxp
 * @subpackage Wp_Dxp/admin/partials
 */
?>

<!-- This file should primarily consist of HTML with a little bit of PHP. -->

<div class="container-fluid pl-0 pr-0 wp-dxp-header-nav">

    <?php
    require_once plugin_dir_path( dirname( __FILE__ ) ) . '_other/wp-dxp-header-nav.php'; ?>

</div>

<section class="section mb-0 wp-dxp-body-content">
    <div class="container-fluid">
        <div class="row">
            <div class="col-12">
                <?php
                if (!$rule->is_usable) :
                    $error = 'This rule is not currently usable for the following reasons:' . '<br /><br />- ' . implode('<br />- ', $rule->getConditionDependencyIssues()) ?>
                    <div class="alert alert-danger">
                        <?php echo $error; ?>
                    </div>
                <?php
                endif; ?>
            </div>
        </div>
    </div>
    <div class="container-fluid">
        <div class="row mb-lg-2">
            <div class="col-12 d-inline-flex align-items-center justify-content-between">
                <h2 class="h4 section-title mb-2"><?php _e('Edit Rule', 'wp-dxp'); ?>: <?php echo $rule->name; ?></h2>
            </div>
        </div>
        <div class="row mb-3">
            <div class="col-12">
                <p class="section-description"><?php _e('Edit the rule details and conditions using the form below. When finished, click on Save to update the rule.', 'wp-dxp'); ?></p>
            </div>
        </div>
    </div>
</section>

<section class="section">
    <div class="container-fluid">
        <div class="row mb-lg-2">
            <div class="col-12 col-lg-10">

				<form action="<?php echo $rule->edit_url; ?>" method="post" accept-charset="UTF-8" id="wp-dxp-rule-form">
					<?php
					include_once('_form.php'); ?>
				</form>

            </div>
        </div>
    </div>
</section>


<section class="section">
    <div class="container-fluid">
        <div class="row mb-lg-2">
            <div class="col-12 col-lg-10">
				<h2 class="h4 section-title mb-2"><?php _e('Used on', 'wp-dxp'); ?></h2>
            </div>
        </div>
        <div class="row mb-2">
            <div class="col-12">
                <p class="section-description"><?php _e('This table shows the blocks that this rule is currently present on.', 'wp-dxp'); ?></p>
            </div>
        </div>
        <div class="row">
            <div class="col-12 col-lg-10">

				<table class="datatable_rules table table-striped table-bordered">
					<thead>
						<tr>
							<th><?php _e('Page', 'wp-dxp'); ?></th>
							<th><?php _e('Block', 'wp-dxp'); ?></th>
							<th>&nbsp;</th>
						</tr>
					</thead>

					<tbody>
					<?php
					if (count($rule->usage_blocks)) :
						foreach ($rule->usage_blocks as $i => $block) : ?>
						<tr class="<?php echo $i % 2 ? 'alternate' : ''; ?>">
							<td><?php echo esc_attr($block->post_title); ?></td>
							<td><?php echo esc_attr($block->block_name); ?></td>
							<td class="d-flex justify-content-center">
				            	<a class="table-link mx-1" href="<?php echo $block->post_edit_url; ?>"><?php _e('Edit', 'wp-dxp'); ?></a>
							</td>
						</tr>
				        <?php
				    	endforeach;
					else : ?>
						<tr>
							<td class="column-columnname" colspan="3"><?php _e('There are no blocks using this rule', 'wp-dxp'); ?></td>
						</tr>
					<?php
				    endif; ?>
					</tbody>
				</table>
			</div>
		</div>
	</div>
</section>

<?php
require_once plugin_dir_path( dirname( __FILE__ ) ) . '_other/wp-dxp-footer.php'; ?>