<?php
class Wp_Dxp_Base_Condition extends Wp_Dxp_Singleton {

	public $description = '';

	public $category = '';

	/**
	 * Standard comparators for a condition
	 * @var array
	 */
	protected $comparators = [
		'equals' => 'Equals',
		'does_not_equal' => 'Does Not Equal',
		'any' => 'Is any of',
	];

	/**
	 * Potential values used for a comparison
	 * @var array
	 */
	protected $comparisonValues = [
		'true' => 'True',
		'false' => 'False',
	];

	/**
	 * Condition identifier - must be unique
	 * @var string
	 */
	public $identifier;

	/**
	 * Constructor
	 */
	public function __construct() {}

	/**
	 * Test data against condition
	 * @param  string $comparator
	 * @param  mixed $value
	 * @return boolean
	 */
	public function matchesCriteria($comparator, $value, $action) { }

	/**
	 * Retrieve potential comparator values
	 * @return array
	 */
	public function getComparators()
	{
		return $this->comparators;
	}

	/**
	 * Retrieve potential comparison values
	 * @return array
	 */
	public function getComparisonValues()
	{
		return $this->comparisonValues;
	}

	/**
	 * Convert to object (usually for json on page)
	 * @return stdClass
	 */
	public function toObject()
	{
		return (object) [
			'identifier' => $this->identifier,
			'comparators' => $this->comparators,
			'comparisonValues' => $this->getComparisonValues(),
		];
	}

	/**
	 * Check that the dependencies are met for the condition to be used
	 * @return boolean
	 */
	public function isUsable()
	{
		foreach ($this->dependencies() as $dependency) {
			if (!$dependency->verify()) {
				return false;
			}
		}

		return true;
	}

	/**
	 * Array of dependencies for the condition to be used
	 * @return array
	 */
	public function dependencies()
	{
		return [];
	}
	
	/**
	 * Array of tag attributes to be included in WP DXP tag given the chosen condition
	 * @param  StdClass $condition
	 * @param  string $action
	 * @return array
	 */
	public function tagAttributes($condition, $action)
	{
		return [];
	}

}