<?php
use GeoIp2\Database\Reader;

class Wp_Dxp_Condition_GravityForms_Completed_Form_Submission extends Wp_Dxp_Base_Condition {

	public $description = "User has submitted a form";

	public $identifier = 'gravityforms_completed_form_submission';

	public $category = 'Gravity Forms';

	/**
	 * Constructor
	 */
	public function __construct() {
		parent::__construct();

		$this->comparators = [
			'equals' => 'Is',
		];

		$this->comparisonValues = [
			'true' => 'True',
			'false' => 'False',
		];
	}

	/**
	 * Test data against condition
	 * @param  string $comparator
	 * @return boolean
	 */
	public function matchesCriteria($comparator, $value, $action)
	{
		switch ($comparator) {
			case 'equals':
				return $this->comparatorEquals($value);
		}

		return false;
	}

	/**
	 * "Equal" test
	 * @return boolean
	 */
	public function comparatorEquals($value)
	{
		if (is_user_logged_in()) {
			$forms = GFAPI::get_forms();

			$searchCriteria = [
		        'field_filters' => [
	            	[
	                	'key' => 'created_by', 'value' => get_current_user_id(), //Current logged in user
	            	]
	          	]
	        ];

	        $submissionCount = 0;
	        foreach ($forms as $form) {
		        $entry_count = GFAPI::count_entries($form['id'], $searchCriteria);

		        $submissionCount += $entry_count;
		    }

		    if ($value == 'true') {
		    	return $submissionCount > 0;
		    }

		    return $submissionCount == 0;
		}

		return false;
	}

	/**
	 * Array of dependencies for the condition to be used
	 * @return array
	 */
	public function dependencies()
	{
		return [
			Wp_Dxp_Dependency_GravityForms_Activated::getInstance(),
		];
	}
}