<?php
class Wp_Dxp_Base_Model {

	protected static $table = '';

	protected $data = [];

    protected $attributes = [];

	/**
	 * Constructor
	 * @param array $attributes [description]
	 */
	public function __construct($attributes = [])
	{
		foreach ($this->attributes as $attribute) {
			$this->$attribute = null;
		}

		if ($attributes) {
			$this->hydrateFromArray($attributes);
		}
	}

	/**
	 * Save Model
	 * @return null
	 */
    public function save()
    {
    	global $wpdb;

    	$table = self::getTableName();
    	$this->modified_at = date('Y-m-d H:i:s');

    	if ($this->id) {
    		$wpdb->update($wpdb->prefix.$table, $this->data, ['id'=>$this->id]);
    	} else {
    		$this->created_at = date('Y-m-d H:i:s');
    		$wpdb->insert($wpdb->prefix.$table, $this->data);
    		$this->id = $wpdb->insert_id;
    	}
    }

    /**
     * Clone this model and save
     * @return Wp_Dxp_Base_Model
     */
    public function clone()
    {
        $this->id = NULL;
        $this->name = 'Copy of ' . $this->name;

        $this->save();

        return $this;
    }

    /**
     * Populate model attributes from array of data
     * @param  array $attributes
     */
    protected function hydrateFromArray($attributes)
    {
    	foreach ($attributes as $key => $value) {
    		$this->$key = $value;
    	}
    }

    /**
     * Find model via ID
     * @param  integer $id
     * @return Wp_Dxp_Base_Model|false
     */
    public static function find($id)
    {
        global $wpdb;

        $table = self::getTableName();

        $sql = $wpdb->prepare("SELECT * FROM {$wpdb->prefix}{$table} WHERE id = %d;", [$id]);
        $attributes = $wpdb->get_row($sql, ARRAY_A);

        if (!$attributes) {
            return false;
        }

        return new static($attributes);
    }

    /**
     * Get all models
     * @return array
     */
    public static function all()
    {
        global $wpdb;

        $table = self::getTableName();

        $sql = "SELECT * FROM {$wpdb->prefix}{$table} ORDER BY id ASC;";
        $rows = $wpdb->get_results($sql, ARRAY_A);

        $return = [];
        foreach ($rows as $row) {
            $return[] = new static($row);
        }

        return $return;
    }

    /**
     * Get all models
     * @return array
     */
    public static function inCategory($category_id)
    {
        global $wpdb;

        $table = self::getTableName();

        $sql = "SELECT * FROM {$wpdb->prefix}{$table} ORDER BY id ASC;";
        $sql = $wpdb->prepare("SELECT * FROM {$wpdb->prefix}{$table} WHERE category_id = %d;", [$category_id]);
        $wpdb->query($sql);
        $rows = $wpdb->get_results($sql, ARRAY_A);

        $return = [];
        foreach ($rows as $row) {
            $return[] = new static($row);
        }

        return $return;
    }

    /**
     * Delete model for specified ID
     * @param  inteer $id
     * @return boolean
     */
    public static function delete($id)
    {
        global $wpdb;

        $table = self::getTableName();

        $sql = $wpdb->prepare("DELETE FROM {$wpdb->prefix}{$table} WHERE id = %d;", [$id]);
        return $wpdb->query($sql);
    }

    /**
     * Get models as list with specified properties as key & value
     * @return array
     */
    public static function list($key = 'id', $value = 'name')
    {
        $rows = static::all();

        $list = [];
        foreach ($rows as $row) {
            $list[$row->$key] = $row->$value;
        }

        return $list;
    }

    /**
     * Magic Getter
     * @param  string $property
     * @return mixed
     */
    public function __get($property)
    {
        if (in_array($property, $this->attributes)) {
            return stripslashes_deep($this->data[$property]);
        }

        // Allow for custom attribute getters
        $attrMethodName = 'get' . str_replace('_', '', ucwords($property, '_')) . 'Attribute';

        if (method_exists($this, $attrMethodName)) {
            return stripslashes_deep($this->$attrMethodName());
        }

        return null;
    }

    /**
     * Magic setter
     * @param string $property
     * @param mixed $value
     */
    public function __set($property, $value)
    {
        if (in_array($property, $this->attributes)) {
            $this->data[$property] = $value;
        }
    }

    /**
     * Return the table name for the class
     * @return string
     */
    public static function getTableName()
    {
    	return static::$table;
    }

}